==> qtjambi-sensors-6.5.3-sources.jar: io/qt/sensors/QAmbientTemperatureSensor.java <==
package io.qt.sensors;

import io.qt.*;


/**
 * <p>Convenience wrapper around QSensor</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qambienttemperaturesensor.html">QAmbientTemperatureSensor</a></code></p>
 */
public class QAmbientTemperatureSensor extends io.qt.sensors.QSensor
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QAmbientTemperatureSensor.class);
    
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qambienttemperaturesensor.html#QAmbientTemperatureSensor">QAmbientTemperatureSensor::<wbr>QAmbientTemperatureSensor(QObject*)</a></code></p>
     */
    public QAmbientTemperatureSensor(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QAmbientTemperatureSensor instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qsensor.html#reading-prop">QSensor::<wbr>reading()const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.sensors.@Nullable QAmbientTemperatureReading reading(){
        return reading_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.sensors.QAmbientTemperatureReading reading_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QAmbientTemperatureSensor(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * @hidden
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QAmbientTemperatureSensor(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QAmbientTemperatureSensor instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QAmbientTemperatureSensor(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QAmbientTemperatureSensor() {
        this((io.qt.core.QObject)null);
    }
}

==> qtjambi-sensors-6.7.1-sources.jar: io/qt/sensors/QAmbientTemperatureSensor.java <==
package io.qt.sensors;

import io.qt.*;


/**
 * <p>Convenience wrapper around QSensor</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qambienttemperaturesensor.html">QAmbientTemperatureSensor</a></code></p>
 */
public class QAmbientTemperatureSensor extends io.qt.sensors.QSensor
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QAmbientTemperatureSensor.class);
    
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qambienttemperaturesensor.html#QAmbientTemperatureSensor">QAmbientTemperatureSensor::<wbr/>QAmbientTemperatureSensor(QObject*)</a></code></p>
     */
    public QAmbientTemperatureSensor(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QAmbientTemperatureSensor instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qsensor.html#reading-prop">QSensor::<wbr/>reading()const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.sensors.@Nullable QAmbientTemperatureReading reading(){
        return reading_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.sensors.QAmbientTemperatureReading reading_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QAmbientTemperatureSensor(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     * @hidden
     */
    @NativeAccess
    protected QAmbientTemperatureSensor(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QAmbientTemperatureSensor instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QAmbientTemperatureSensor(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QAmbientTemperatureSensor() {
        this((io.qt.core.QObject)null);
    }
}
